==> scs-core-3.1.10.tar.gz: scs-core-3.1.10/src/scs_core/aws/security/cognito_login_manager.py <==
"""
Created on 23 Nov 2021

@author: Bruno Beloff (bruno.beloff@southcoastscience.com)
"""

import requests

from scs_core.aws.client.api_client import APIClient
from scs_core.aws.security.cognito_authentication import AuthenticationResult


# --------------------------------------------------------------------------------------------------------------------

class CognitoLoginManager(APIClient):
    """
    classdocs
    """

    __URL = 'https://lnh2y9ip75.execute-api.us-west-2.amazonaws.com/default/CognitoLogin'
    __AUTH = '@southcoastscience.com'


    # ----------------------------------------------------------------------------------------------------------------

    def __init__(self):
        super().__init__()


    # ----------------------------------------------------------------------------------------------------------------

    def user_login(self, credentials):
        url = '/'.join((self.__URL, 'user'))
        headers = self._auth_headers(self.__AUTH)

        response = requests.post(url, headers=headers, json=credentials.as_json())
        self._check_response(response)

        return AuthenticationResult.construct_from_res(response)


    def device_login(self, credentials):
        url = '/'.join((self.__URL, 'device'))
        headers = self._auth_headers(self.__AUTH)

        response = requests.post(url, headers=headers, json=credentials.as_json())
        self._check_response(response)

        return AuthenticationResult.construct_from_res(response)

==> scs-core-3.10.3.tar.gz: scs-core-3.10.3/src/scs_core/aws/security/cognito_login_manager.py <==
"""
Created on 23 Nov 2021

@author: Bruno Beloff (bruno.beloff@southcoastscience.com)
"""

import requests

from scs_core.aws.client.api_client import APIClient
from scs_core.aws.config.aws_endpoint import AWSEndpoint
from scs_core.aws.security.cognito_authentication import AuthenticationResult


# --------------------------------------------------------------------------------------------------------------------

class Endpoint(AWSEndpoint):
    @classmethod
    def configuration(cls):
        return cls('CogSecAPI/CognitoLogin',
                   'https://lnh2y9ip75.execute-api.us-west-2.amazonaws.com/default/CognitoLogin')


# --------------------------------------------------------------------------------------------------------------------

class CognitoLoginManager(APIClient):
    """
    classdocs
    """

    # ----------------------------------------------------------------------------------------------------------------

    def __init__(self):
        super().__init__()


    # ----------------------------------------------------------------------------------------------------------------

    def user_login(self, credentials):
        url = Endpoint.url('user')
        headers = self._auth_headers()

        response = requests.post(url, headers=headers, json=credentials.as_json())
        self._check_response(response)

        return AuthenticationResult.construct_from_res(response)


    def device_login(self, credentials):
        url = Endpoint.url('device')
        headers = self._auth_headers()

        response = requests.post(url, headers=headers, json=credentials.as_json())
        self._check_response(response)

        return AuthenticationResult.construct_from_res(response)
